#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const compiler_1 = require("./compiler");
const path = require("path");
const program = require("commander");
const Rx = require("rxjs/Rx");
const glob = require("glob");
const npmPackage = require(path.join(__dirname, '..', 'package.json'));
const globRx = Rx.Observable.bindNodeCallback(glob);
program
    .version(npmPackage.version);
program
    .command('compile <src...>')
    .description('compile words lists into simple dictionary files.')
    .option('-o, --output <path>', 'Specify the output directory, otherwise files are written back to the same location.')
    .option('-n, --no-compress', 'By default the files are Gzipped, this will turn that off.')
    .action((src, options) => {
    console.log('Compile:\n output: %s\n compress: %s\n files:\n  %s \n\n', options.output || 'default', options.compress ? 'true' : 'false', src.join('\n  '));
    const ext = '.txt' + (options.compress ? '.gz' : '');
    Rx.Observable.from(src)
        .flatMap(src => globRx(src))
        .flatMap(s => s)
        .map(s => {
        const outFilename = path.basename(s).replace(/(\.txt|\.dic|\.aff)?$/, ext);
        const dir = options.output ? options.output : path.dirname(s);
        return [s, path.join(dir, outFilename)];
    })
        .concatMap(([src, dst]) => {
        console.log('Process "%s" to "%s"', src, dst);
        return compiler_1.compileWordList(src, dst).then(() => src);
    })
        .forEach(name => console.log(`Complete.`));
});
program
    .command('compile-trie <src...>')
    .description('Compile words lists or Hunspell dictionary into trie files used by cspell.')
    .option('-o, --output <path>', 'Specify the output directory, otherwise files are written back to the same location.')
    .option('-n, --no-compress', 'By default the files are Gzipped, this will turn that off.')
    .action((src, options) => {
    console.log('Compile:\n output: %s\n compress: %s\n files:\n  %s \n\n', options.output || 'default', options.compress ? 'true' : 'false', src.join('\n  '));
    const ext = '.trie' + (options.compress ? '.gz' : '');
    Rx.Observable.from(src)
        .flatMap(src => globRx(src))
        .flatMap(s => s)
        .map(s => {
        const outFilename = path.basename(s).replace(/(\.txt|\.dic|\.aff)?$/, ext);
        const dir = options.output ? options.output : path.dirname(s);
        return [s, path.join(dir, outFilename)];
    })
        .concatMap(([src, dst]) => {
        console.log('Process "%s" to "%s"', src, dst);
        return compiler_1.compileTrie(src, dst).then(() => src);
    })
        .forEach(name => console.log(`Complete.`));
});
program.parse(process.argv);
if (!process.argv.slice(2).length) {
    program.help();
}
//# sourceMappingURL=app.js.map